<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

if ( ! function_exists( 'pleased_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Pleased Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pleased_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'pleased_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pleased_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Pleased Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pleased_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'pleased_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pleased_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Pleased Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pleased_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'pleased_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if banner section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[banner_section_enable]' )->value() );
}

/**
 * Check if banner section content type is custom.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_banner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[banner_content_type]' )->value();
	return pleased_pro_is_banner_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if banner section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[banner_content_type]' )->value();
	return pleased_pro_is_banner_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if banner section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[banner_content_type]' )->value();
	return pleased_pro_is_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[about_content_type]' )->value();
	return pleased_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[about_content_type]' )->value();
	return pleased_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[about_content_type]' )->value();
	return pleased_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if gallery section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[gallery_content_type]' )->value();
	return pleased_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is activity.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_gallery_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[gallery_content_type]' )->value();
	return pleased_pro_is_gallery_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if gallery section content type is destination.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_gallery_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[gallery_content_type]' )->value();
	return pleased_pro_is_gallery_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if gallery section content type is trip types.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_gallery_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[gallery_content_type]' )->value();
	return pleased_pro_is_gallery_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if package section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if package section content type is trip.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[package_content_type]' )->value();
	return pleased_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if offer section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[offer_section_enable]' )->value() );
}

/**
 * Check if offer section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if offer section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if offer section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if offer section content type is trip.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if offer section content type is activity.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if offer section content type is destination.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if offer section content type is trip types.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_offer_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[offer_content_type]' )->value();
	return pleased_pro_is_offer_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[service_content_type]' )->value();
	return pleased_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[service_content_type]' )->value();
	return pleased_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[service_content_type]' )->value();
	return pleased_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[service_content_type]' )->value();
	return pleased_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[testimonial_content_type]' )->value();
	return pleased_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[blog_content_type]' )->value();
	return pleased_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[blog_content_type]' )->value();
	return pleased_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[blog_content_type]' )->value();
	return pleased_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pleased_pro_theme_options[blog_content_type]' )->value();
	return pleased_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Pleased Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pleased_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'pleased_pro_theme_options[contact_section_enable]' )->value() );
}
