<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 * @return array An array of default values
 */

function pleased_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$pleased_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> false,
		'nav_search_enable'				=> true,
		'menu_type'						=> 'classic-menu',

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'pleased-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'pleased-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'pleased-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'pleased-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Banner,About Us,Gallery,Package,Offer,Services,Testimonial,Blog,Contact',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'pleased-pro' ),
		'hide_date' 					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Banner
		'banner_section_enable'			=> true,
		'banner_search_filter_enable'	=> true,
		'banner_content_type'			=> 'page',
		'banner_title'					=> esc_html__( 'You are invited here to enjoy life', 'pleased-pro' ),
		'banner_sub_title'				=> esc_html__( 'Pleased Travel', 'pleased-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_sub_title'				=> esc_html__( 'About Us', 'pleased-pro' ),
		'about_title'					=> esc_html__( 'We know how to please you & your family', 'pleased-pro' ),
		'about_description'				=> esc_html__( 'Make memories at Travel Luxe, Amelia Island, where southern charm, magnificent scenery and casually elegant surroundings exemplify the gentle ambience of this barrier island luxury beachfront resort. Travel Luxe is the perfect place to feed your spirit. With recently renovated rooms and a bolder focus on cuisine culture & more.', 'pleased-pro' ),
		'about_btn_title'				=> esc_html__( 'Discover More', 'pleased-pro' ),

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_background_image'		=> get_template_directory_uri() . '/assets/uploads/gallery.jpg',
		'gallery_btn_label'				=> esc_html__( 'View More Photos', 'pleased-pro' ),

		// Package
		'package_section_enable'		=> true,
		'package_title'					=> esc_html__( 'Luxurious Packages', 'pleased-pro' ),
		'package_sub_title'				=> esc_html__( 'The pleasure of luxury', 'pleased-pro' ),
		'package_btn_title'				=> esc_html__( 'View All Packages', 'pleased-pro' ),
		'package_content_type'			=> 'category',

		// Offer
		'offer_section_enable'			=> true,
		'offer_content_type'			=> 'category',
		'offer_count'					=> 2,
		'offer_sub_title'				=> esc_html__( 'Best Deal', 'pleased-pro' ),
		'offer_btn_label'				=> esc_html__( 'Book Now', 'pleased-pro' ),
		'offer_background_image'		=> get_template_directory_uri() . '/assets/uploads/special.jpg',

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',
		'service_title'					=> esc_html__( 'Our Services', 'pleased-pro' ),
		'service_sub_title'				=> esc_html__( 'What We Offer', 'pleased-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_background_image'	=> get_template_directory_uri() . '/assets/uploads/testimonial.jpg',
		'testimonial_seperator_image'	=> get_template_directory_uri() . '/assets/uploads/testimonial-01.jpg',

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_title'					=> esc_html__( 'Our Latest Blogs', 'pleased-pro' ),
		'blog_sub_title'				=> esc_html__( 'Happening around us', 'pleased-pro' ),
		'blog_btn_title'				=> esc_html__( 'Discover More', 'pleased-pro' ),

		// Contact
		'contact_section_enable'		=> true,
		'contact_title'					=> esc_html__( 'Contact us', 'pleased-pro' ),
		'contact_sub_title'				=> esc_html__( 'Contact us for more info, Amelia Island, where southern charm, magnify scenery and casually elegant.', 'pleased-pro' ),
		'contact_email'					=> 'noreply@themepalace.com',
		'contact_phone'					=> '+0 00 0000000',
		'contact_social'				=> 'www.facebook.com',
		'contact_address'				=> esc_html__( '265 Street, Manbhawan, Lalitpur', 'pleased-pro' ),
		
	);

	$output = apply_filters( 'pleased_pro_default_theme_options', $pleased_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}