<?php
/**
 * Package section
 *
 * This is the template for the content of package section
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */
if ( ! function_exists( 'pleased_pro_add_package_section' ) ) :
    /**
    * Add package section
    *
    *@since Pleased Pro 1.0.0
    */
    function pleased_pro_add_package_section() {
    	$options = pleased_pro_get_theme_options();
        // Check if package is enabled on frontpage
        $package_enable = apply_filters( 'pleased_pro_section_status', true, 'package_section_enable' );

        if ( true !== $package_enable ) {
            return false;
        }
        // Get package section details
        $section_details = array();
        $section_details = apply_filters( 'pleased_pro_filter_package_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render package section now.
        pleased_pro_render_package_section( $section_details );
    }
endif;

if ( ! function_exists( 'pleased_pro_get_package_section_details' ) ) :
    /**
    * package section details.
    *
    * @since Pleased Pro 1.0.0
    * @param array $input package section details.
    */
    function pleased_pro_get_package_section_details( $input ) {
        $options = pleased_pro_get_theme_options();

        // Content type.
        $package_content_type  = $options['package_content_type'];
        
        $content = array();
        switch ( $package_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['package_content_category'] ) ? $options['package_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 4,
                    'cat'               => $cat_id,
                    'ignore_sticky_posts'   => true,
                    );    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['package_content_page_' . $i] ) )
                        $page_ids[] = $options['package_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 4,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['package_content_post_' . $i] ) )
                        $post_ids[] = $options['package_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 4,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                $page_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['package_content_trip_' . $i] ) )
                        $page_ids[] = $options['package_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 4,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                $cat_id = ! empty( $options['package_content_trip_types'] ) ? $options['package_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 4,
                    );                    
            break;

            case 'destination':
                $cat_id = ! empty( $options['package_content_destination'] ) ? $options['package_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 4,
                    );                    
            break;

            case 'activity':
                $cat_id = ! empty( $options['package_content_activity'] ) ? $options['package_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => 4,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// package section content details.
add_filter( 'pleased_pro_filter_package_section_details', 'pleased_pro_get_package_section_details' );


if ( ! function_exists( 'pleased_pro_render_package_section' ) ) :
  /**
   * Start package section
   *
   * @return string package content
   * @since Pleased Pro 1.0.0
   *
   */
   function pleased_pro_render_package_section( $content_details = array() ) {
        $options = pleased_pro_get_theme_options();
        $package_content_type  = $options['package_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="luxury-room" class="page-section">
                <div class="wrapper">
                    <div class="section-header align-center">
                        <?php if ( ! empty( $options['package_sub_title'] ) ) : ?>
                            <span class="section-subtitle"><?php echo esc_html( $options['package_sub_title'] ); ?></span>
                        <?php endif; 

                        if ( ! empty( $options['package_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['package_title'] ) ?></h2>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <div class="grid">

                            <?php foreach ( $content_details as $content ) : ?>
                                <div class="grid-item">
                                    <article class="has-featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <div class="overlay"></div>
                                        <div class="entry-container">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>

                                            <?php if ( ! in_array( $package_content_type, array( 'page', 'post', 'category' ) ) ) : 
                                                $enable_sale     = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                                $trip_price      = wp_travel_get_trip_price( $content['id'] );
                                                $sale_price      = wp_travel_get_trip_sale_price( $content['id'] );
                                                $trip_per        = get_post_meta( $content['id'], 'wp_travel_price_per', true );
                                                $settings        = wp_travel_get_settings();
                                                $currency_code   = ( isset( $settings['currency'] ) ) ? $settings['currency'] : '';
                                                $currency_symbol = wp_travel_get_currency_symbol( $currency_code );
                                            ?>
                                                <div class="trip-entry-meta">
                                                   <div class="price-meta">
                                                        <span class="trip-price">                       
                                                            <?php 
                                                            echo esc_html( $currency_symbol );
                                                            echo ( true == $enable_sale && $sale_price ) ? esc_html( $sale_price ) : esc_html( $trip_price );
                                                            ?>
                                                        </span><!-- .trip-price -->
                                                        <span><?php printf( esc_html__( '/ %s', 'pleased-pro' ), $trip_per ); ?></span><!-- .trip-price -->
                                                    </div>
                                                </div><!-- .entry-meta -->
                                            <?php endif; ?>
                                        </div><!-- .entry-container -->  
                                    </article>   
                                </div><!-- .grid-item -->
                            <?php endforeach; ?>

                        </div><!-- .grid -->
                        <?php if ( ! empty( $options['package_btn_title'] ) && ! empty( $options['package_btn_url'] ) ) : ?>
                            <a href="<?php echo esc_url( $options['package_btn_url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $options['package_btn_title'] ); ?></a>
                        <?php endif; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #luxury-room -->
        
    <?php }
endif;